// Copyright (c) 2021, Philipp Matthias Schäfer (philipp.matthias.schaefer@posteo.de)
//
// This file is part of the WebLDAPPasswd application.
//
// The WebLDAPPasswd application is free software: you can redistribute it
// and/or modify it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the License or
// (at your option) any later version.
//
// The WebLDAPPasswd application is distributed in the hope that it will be
// useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero
// General Public License for more details.
//
// You should have received a copy of the GNU General Affero Public License
// along with the WebLDAPPasswd. If not, see <https://www.gnu.org/licenses/>.
use std::io::BufReader;
use std::fs::File;

use anyhow::{Context, Result};
use handlebars::Handlebars;
use serde_derive::Deserialize;
use serde_json::json;

fn default_headline() -> String {
    "Change your password".to_string()
}

fn default_ldap_url() -> String {
    "ldap://localhost".to_string()
}

fn default_host() -> String {
    "localhost".to_string()
}

fn default_port() -> u16 {
    8000
}

#[derive(Deserialize)]
pub struct Config {
    pub dn: String,

    #[serde(default = "default_headline")]
    pub headline: String,

    #[serde(default = "default_ldap_url")]
    pub ldap_url: String,

    #[serde(default = "default_host")]
    pub host: String,

    #[serde(default = "default_port")]
    pub port: u16,
}

pub fn load(file_path: &str) -> Result<Config> {
    let file = File::open(file_path).
        with_context(|| format!("Failed to open configuration file '{}'",
                                file_path))?;

    let config: Config = serde_json::from_reader(BufReader::new(file))
        .with_context(|| format!("Failed to parse configuration file '{}'",
                                 file_path))?;

    Handlebars::new()
        .render_template(&config.dn, &json!({"username" : "foo"}))
        .with_context(|| format!(
            "Failed to render DN ({}) from configuration file '{}'",
            config.dn,
            file_path
        ))?;

    Ok(config)
}
