use anyhow::{Context as AnyhowContext, Result};
use handlebars::Handlebars;
use serde_json::json;

use crate::config::Config;

pub struct Context {
    pub dn: String,
    pub index_html: String,
    pub ldap_url: String,
}

impl Context {
    pub fn new(config: &Config) -> Result<Context> {
        let index_html = Handlebars::new()
            .render_template(include_str!("static/index.html.hbs"),
                             &json!({"headline" : config.headline}))
            .with_context(|| format!(
                "Failed to render index.html from template and configured headline '{}'",
                config.headline
            ))?;

        Ok(Context{
            dn: config.dn.clone(),
            index_html,
            ldap_url: config.ldap_url.clone(),
        })
    }
}
