// Copyright (c) 2021, Philipp Matthias Schäfer (philipp.matthias.schaefer@posteo.de)
//
// This file is part of the WebLDAPPasswd application.
//
// The WebLDAPPasswd application is free software: you can redistribute it
// and/or modify it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the License or
// (at your option) any later version.
//
// The WebLDAPPasswd application is distributed in the hope that it will be
// useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero
// General Public License for more details.
//
// You should have received a copy of the GNU General Affero Public License
// along with the WebLDAPPasswd. If not, see <https://www.gnu.org/licenses/>.
use rocket::http::{ContentType, Status};
use rocket::request::Request;
use rocket::response::{content, Responder, Response};

use rocket::get;

use crate::context::Context;

pub struct Svg<R>(pub R);

impl<'r, R: Responder<'r>> Responder<'r> for Svg<R> {
    fn respond_to(self, req: &Request) -> Result<Response<'r>, Status> {
        content::Content(ContentType::SVG, self.0).respond_to(req)
    }
}

#[get("/")]
pub fn index(context: rocket::State<Context>) -> content::Html<String> {
    content::Html(context.index_html.clone())
}

#[get("/checkmark.svg")]
pub fn checkmark() -> Svg<&'static str> {
    Svg(include_str!("static/checkmark.svg"))
}

#[get("/cross.svg")]
pub fn cross() -> Svg<&'static str> {
    Svg(include_str!("static/cross.svg"))
}

#[get("/hourglass.svg")]
pub fn hourglass() -> Svg<&'static str> {
    Svg(include_str!("static/hourglass.svg"))
}

#[get("/logo.svg")]
pub fn logo() -> Svg<&'static str> {
    Svg(include_str!("static/logo.svg"))
}

#[get("/legal.html")]
pub fn legal() -> content::Html<&'static str> {
    content::Html(include_str!("static/legal.html"))
}

#[get("/webldappasswd.css")]
pub fn css() -> content::Css<&'static str> {
    content::Css(include_str!("static/webldappasswd.css"))
}

#[get("/webldappasswd.js")]
pub fn js() -> content::JavaScript<&'static str> {
    content::JavaScript(include_str!("static/webldappasswd.js"))
}
