// Copyright (c) 2021, Philipp Matthias Schäfer (philipp.matthias.schaefer@posteo.de)
//
// This file is part of the WebLDAPPasswd application.
//
// The WebLDAPPasswd application is free software: you can redistribute it
// and/or modify it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the License or
// (at your option) any later version.
//
// The WebLDAPPasswd application is distributed in the hope that it will be
// useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Affero
// General Public License for more details.
//
// You should have received a copy of the GNU General Affero Public License
// along with the WebLDAPPasswd. If not, see <https://www.gnu.org/licenses/>.
MODAL_STATES = {
  "Wait" : {
    button_disabled : true,
    message : "Waiting for server response ...",
    icon_url : "hourglass.svg",
  },
  "Success" : {
    button_disabled : false,
    message : "Password changed",
    icon_url : "checkmark.svg",
  },
  "FillAllFields" : {
    button_disabled : false,
    message : "You have to fill all three input fields",
    icon_url : "cross.svg",
  },
  "FetchError" : {
    button_disabled : false,
    message : "An error occurred while contacting the server",
    icon_url : "cross.svg",
  },
  "ServerError" : {
    button_disabled : false,
    message : "A server error occurred. Password was not changed.",
    icon_url : "cross.svg",
  },
  "InvalidCredentials" : {
    button_disabled : false,
    message : "Invalid credentials provided. Password was not changed.",
    icon_url : "cross.svg",
  },
}

function showModal(state_name) {
  const state = MODAL_STATES[state_name];

  const message = document.getElementById("message");

  const img = message.childNodes[0];
  img.src = state.icon_url;

  const text = message.childNodes[1];
  text.textContent = " " + state.message;

  const button = document.getElementById("close_button");
  button.disabled = state.button_disabled;

  const modal = document.getElementById("modal");
  modal.style.display = 'flex';
}

function hideModal() {
  const modal = document.getElementById("modal");
  modal.style.display = 'none';
}

FIELDS = ['username', 'old_password', 'new_password']

function fields() {
  return FIELDS.map(
    fieldName => document.querySelector(`input[name=${fieldName}]`)
  );
}

function clearFields() {
  fields().forEach(field => {
    field.value = "";
  });
}

function changePasswords() {
  const query = {};

  if(!fields().every(field => field.value.length != 0)) {
    showModal("FillAllFields");
    return;
  }

  fields().forEach(field => {
    query[field.name] = field.value;
  });

  showModal("Wait");

  fetch("update", {
    method: "POST",
    body: JSON.stringify(query),
  }).then(response => {
    switch(response.status) {
    case 202:
      showModal("Success");
      clearFields();
      break;
    case 401:
      showModal("InvalidCredentials");
      break;
    case 500:
      showModal("ServerError");
      break;
    default:
      console.log("Unexpected status code: " + response.status);
      showModal("FetchError");
      break;
    }
  }, error => {
    console.log("Fetch error: " + error);
    showModal("FetchError");
  })
}
